@@ -3,6 +3,7 @@
 #include <QDialogButtonBox>
 #include <QDebug>
 #include <QListView>
+#include <QTreeView>
 #include <QPushButton>
 
 AccountsDialog::AccountsDialog(QStandardItemModel *accounts,
@@ -14,13 +15,18 @@ AccountsDialog::AccountsDialog(QStandardItemModel *accounts,
 
         QHBoxLayout *layout = new QHBoxLayout (this);
 
-        QListView *list = new QListView();
-        list->setModel(accounts);
-        list->setModelColumn(1);
-        list->setProperty("FingerScrollable", true);
-        layout->addWidget(list, 1);
+        QTreeView *tree = new QTreeView();
+        tree->setModel(accounts);
+        tree->setProperty("FingerScrollable", true);
+        tree->setColumnHidden(0, true);
+        tree->setColumnWidth(1, 525);
+        tree->setColumnHidden(2, true);
+        tree->setColumnWidth(3, 50);
+        tree->setHeaderHidden(true);
+        tree->setIconSize(QSize(48, 48));
+        layout->addWidget(tree, 1);
 
-        connect (list, SIGNAL(activated(const QModelIndex&)),
+        connect (tree, SIGNAL(activated(const QModelIndex&)),
                  this, SLOT(detailsSelected(const QModelIndex&)));
 
         QDialogButtonBox *box = new QDialogButtonBox();
