@@ -25,7 +25,7 @@ Controller::Controller()
 
         settings = new QSettings (configFile, QSettings::NativeFormat, this);
         concepts = new QStandardItemModel(0, 0, this);
-        accounts = new QStandardItemModel(0, 3, this);
+        accounts = new QStandardItemModel(0, 4, this);
         scheduled = new QStandardItemModel(0, 7, this);
 
         loadConcepts();
@@ -51,6 +51,8 @@ Controller::Controller()
                                                     accounts->item(row, 1)->text(),
                                                     accounts->item(row, 2)->text().toDouble(),
                                                     this);
+                        QIcon icon(QString(ACTIVE_ACCOUNT_ICON));
+                        accounts->item(row, 3)->setIcon(icon);
                         /* everything went fine. Load account dependant info */
                         loadScheduled();
                         month = new MonthData(QDate::currentDate(), activeAccount, this);
@@ -128,6 +130,24 @@ void Controller::newAccountConfirmed(Account *a)
         if (!db.exists(a)) {
                 if (db.create(a)) {
                         loadAccounts();
+                        if (accounts->rowCount() == 1) {
+                                /* this is the first account in the system. Activate it */
+                                if (activeAccount != NULL) {
+                                        delete activeAccount;
+                                }
+                                activeAccount = new Account(accounts->item(0, 0)->text().toInt(),
+                                                            accounts->item(0, 1)->text(),
+                                                            accounts->item(0, 2)->text().toDouble(),
+                                                            this);
+                                settings->setValue(ACTIVE_ACCOUNT_KEY, activeAccount->id());
+                                QIcon icon(QString(ACTIVE_ACCOUNT_ICON));
+                                accounts->item(0, 3)->setIcon(icon);
+                                loadScheduled();
+                                month = new MonthData(QDate::currentDate(), activeAccount, this);
+                                loadMonth();
+                                mainWindow.setMonthData(month);
+                        }
+
                 } else {
                         QMaemo5InformationBox::information(&mainWindow, tr("Error creating account"));
                 }
@@ -149,7 +169,7 @@ void Controller::accountsSelected()
 
 void Controller::accountDetailsSelected(QModelIndex index)
 {
-        AccountDetailsDialog dialog(accounts, index.row(), &mainWindow);
+        AccountDetailsDialog dialog(accounts, index.row(), activeAccount, &mainWindow);
 
         connect(&dialog, SIGNAL(deleteAccountConfirmed(Account*)),
                 this, SLOT(deleteAccountConfirmed(Account*)));
@@ -201,6 +221,7 @@ void Controller::selectAccountConfirmed(Account *a)
         activeAccount = a;
         activeAccount->setParent(this);
         settings->setValue(ACTIVE_ACCOUNT_KEY, a->id());
+        loadAccounts();
         loadScheduled();
 
         if (month != NULL) {
@@ -364,8 +385,10 @@ void Controller::deleteConceptConfirmed(Concept *c)
         if (ConfirmationDialog::askConfirmation(message)) {
                 if (db.remove(c)) {
                         loadConcepts();
-                        loadScheduled();
-                        loadMonth(true);
+                        if (activeAccount) {
+                                loadScheduled();
+                                loadMonth(true);
+                        }
                 } else {
                         QMaemo5InformationBox::information(&mainWindow, tr("Error deleting concept"));
                 }
@@ -576,4 +599,15 @@ void Controller::loadAccounts()
 {
         accounts->removeRows(0, accounts->rowCount());
         db.loadAccounts(accounts);
+
+        if (activeAccount) {
+                QList<QStandardItem*> list = accounts->findItems(QString("%1").arg(activeAccount->id()),
+                                                                 Qt::MatchFixedString,
+                                                                 0);
+                if (list.size() != 0) {
+                        int row = list[0]->index().row();
+                        QIcon icon(QString(ACTIVE_ACCOUNT_ICON));
+                        accounts->item(row, 3)->setIcon(icon);
+                }
+        }
 }
