@@ -11,6 +11,7 @@
 #include "concept.h"
 #include "monthdata.h"
 #include "summarydata.h"
+#include "account.h"
 
 class DBManager : public QObject
 {
@@ -22,9 +23,9 @@ class DBManager : public QObject
         bool create(MonthData *month);
         bool load(MonthData *month, bool expensesOnly);
         bool exists(MonthData *month);
-        bool updateBudget(int year, int month, double budget);
+        bool updateBudget(int year, int month, int account, double budget);
 
-        bool create(int year, int month, Expense *e);
+        bool create(int year, int month, int account, Expense *e);
         bool update(Expense *e);
         bool remove(Expense *e);
 
@@ -34,13 +35,20 @@ class DBManager : public QObject
         bool remove(Concept *c);
         bool exists(Concept *c);
 
-        bool createScheduled(Expense *e);
+        bool createScheduled(int account, Expense *e);
         bool removeScheduled(Expense *e);
-        bool loadScheduled(QStandardItemModel *scheduled);
+        bool loadScheduled(int account, QStandardItemModel *scheduled);
         bool updateScheduled(Expense *e);
 
-        bool getDataInterval(int &minYear, int &minMonth, int &maxYear, int &maxMonth);
-        bool load(SummaryData *summary);
+        bool create(Account *a);
+        bool loadAccounts(QStandardItemModel *accounts);
+        bool update(Account *a);
+        bool remove(Account *a);
+        bool exists(Account *a);
+        bool load(Account *a);
+
+        bool getDataInterval(int account, int &minYear, int &minMonth, int &maxYear, int &maxMonth);
+        bool load(int account, SummaryData *summary);
 
  private:
         bool createTables();
