@@ -5,6 +5,8 @@
 #include <QTreeView>
 #include <QPushButton>
 #include <QLabel>
+#include <QIcon>
+#include "global.h"
 
 ExpensesList::ExpensesList(QStandardItemModel *expenses,
                            QWidget *parent)
@@ -18,6 +20,7 @@ ExpensesList::ExpensesList(QStandardItemModel *expenses,
         QVBoxLayout *layout = new QVBoxLayout (this);
 
         QPushButton *newButton = new QPushButton(tr("New"));
+        newButton->setIcon(QIcon(GENERAL_ADD_ICON));
         layout->addWidget(newButton, 0);
         connect(newButton, SIGNAL(clicked()), this, SIGNAL(newExpenseSelected()));
 
